@@ -12,6 +12,8 @@ from PyQt5 import QtCore, QtGui, QtWidgets
 import json
 
 from cryspy import GlobalN, file_to_globaln, RhoChi
+from cryspy import __version__ as cryspy_version
+from cryspy_editor import __version__ as cryspy_editor_version
 
 from cryspy_editor.widgets.w_panel import WPanel, \
     find_tree_item_position, L_GLOBAL_CLS
@@ -280,8 +282,23 @@ class CBuilder(QtWidgets.QMainWindow):
             manip_action.triggered.connect(self.transfer)
             fileMenu.addAction(manip_action)
 
+        about = menubar.addAction("About")
+        about.triggered.connect(self.about)
+
+
         self.statusBar()
 
+    def about(self):
+        val = QtWidgets.QMessageBox.information(
+            self, "About CrysPy",
+            f"Versions:\n\
+    CrysPy Editor - {cryspy_editor_version:} \n\
+    CrysPy library - {cryspy_version:}\n\n\
+To upgrade:\n\
+    python -m pip install --upgrade cryspy cryspy_editor --user\n\n\
+GitHub Page: \n\
+    https://github.com/ikibalin/cryspy")
+
     def transfer(self):
         """Transfer GlobalN object to any one."""
         sender = self.sender()
@@ -442,6 +459,7 @@ class CBuilder(QtWidgets.QMainWindow):
             d_setup = json.load(open(f_setup, 'r'))
         else:
             d_setup = {}
+
         d_setup["last_directory"] = f_name
         s_cont = json.dumps(d_setup, sort_keys=True, indent=4)
         with open(f_setup, "w") as fid:
