@@ -26,7 +26,6 @@ def w_for_presentation(obj, thread: QtCore.QThread) -> tuple:
     """Give tuple of docks for Dockarea."""
     if obj is None:
         return ()
-
     if isinstance(obj, RhoChi):
         docks = dock_rhochi(obj, thread)
         return docks
@@ -52,6 +51,7 @@ def dock_rhochi(obj: RhoChi, thread: QtCore.QThread):
     """Dock for RhoChi object."""
     crystals = obj.crystals()
     experiments = obj.experiments()
+
     docks = []
     flag_crystals = len(crystals) != 0
     flag_experiments = len(experiments) != 0
@@ -64,7 +64,7 @@ def dock_rhochi(obj: RhoChi, thread: QtCore.QThread):
             docks.extend(list(dock_pd2d(experiment, thread)))
         elif isinstance(experiment, Diffrn):
             docks.extend(list(dock_diffrn(experiment, thread)))
-
+    
     if obj.is_defined():
         l_var_name = obj.get_variable_names()
         l_var_name_sigma = [tuple(list(name[:-1]) +
@@ -945,6 +945,7 @@ def dock_crystal(obj: Crystal, thread: QtCore.QThread):
 
 def dock_pd2d(obj:Pd2d, thread: QtCore.QThread):
     f_proc, f_meas, f_bkgr, f_peak = False, False, False, False
+    f_refine_ls = False
     proc, meas, bkgr, peak = None, None, None, None
     try:
         meas = obj.pd2d_meas
@@ -961,16 +962,13 @@ def dock_pd2d(obj:Pd2d, thread: QtCore.QThread):
         f_chi2 = True
     except AttributeError:
         f_chi2 = False
-    try:
+    if obj.is_attribute("refine_ls"):
         refine_ls = obj.refine_ls
         f_refine_ls = True
-    except AttributeError:
-        f_refine_ls = False
-    try:
+    if obj.is_attribute("pd2d_proc"):
         proc = obj.pd2d_proc
         f_proc = True
-    except AttributeError:
-        f_proc = False
+
     l_pd2d_peak = []
     try:
         phase = obj.phase
@@ -1100,10 +1098,12 @@ def dock_pd2d(obj:Pd2d, thread: QtCore.QThread):
         docks.extend(list(dock_chi2(chi2)))
     if f_refine_ls:
         docks.extend(list(dock_refine_ls(refine_ls)))
+
     return tuple(docks)
 
 
 def dock_pd2d_meas(obj:Pd2dMeas):
+    obj.form_object()
     docks = []
     try:
         ttheta = obj.ttheta
@@ -1187,6 +1187,7 @@ def dock_pd2d_meas(obj:Pd2dMeas):
 
 def dock_pd2d_proc(obj:Pd2dProc, l_pd2d_peak: List[Pd2dPeakL]):
     """Docks for pd2d_proc object."""
+    obj.form_object()
     docks = []
     try:
         ttheta = obj.ttheta
@@ -1391,11 +1392,13 @@ def dock_diffrn(obj: Diffrn, thread: QtCore.QThread):
 
     if f_diffrn_refln:
         diffrn_refln = obj.diffrn_refln
-        x = numpy.array(diffrn_refln.fr_calc, dtype=float)
-        y = numpy.array(diffrn_refln.fr, dtype=float)
-        err = numpy.array(diffrn_refln.fr_sigma, dtype=float)
+        flag_calc = diffrn_refln.is_attribute("fr_calc")
+
+        if flag_calc:
+            x = numpy.array(diffrn_refln.fr_calc, dtype=float)
+            y = numpy.array(diffrn_refln.fr, dtype=float)
+            err = numpy.array(diffrn_refln.fr_sigma, dtype=float)
 
-        if not(numpy.all(numpy.isnan(x))):
             vb_1 = pg.ViewBox()
             vb_1.setMouseMode(vb_1.RectMode)
             widget = pg.PlotWidget(viewBox=vb_1)
